@@ -2,7 +2,7 @@ import math
 from scipy.special import gammaln
 from scipy.stats import gamma as gammadist
 import numpy as np
-import ANYstructure_local.PULS.excel_inteface as pulsxl
+#import ANYstructure_local.PULS.excel_inteface as pulsxl
 import ANYstructure_local.helper as hlp
 from multiprocessing import  Pool, cpu_count, Process
 import multiprocessing
@@ -10,7 +10,7 @@ import shutil, os, time, datetime, json
 from itertools import islice
 import pythoncom
 import random, itertools
-
+import PULS.excel_inteface as pulsxl
 import ANYstructure_local.SN_curve_parameters as snc
 
 class Structure():
